@@ -132,8 +132,8 @@ def main(args=None):
         try:
             rl_flag, bases, tops, wct, wct_err = \
                 feature_id(alt_arr[i], sig = prod_arr[i], sig_err = prod_err_arr[i],
-                           alpha = alphas[i], snr_factor = snr_factor, 
-                           wct_peak_margin = wct_peak_margin, log = logger)
+                           alpha = alphas[i], snr_factor = snr_factor[i], 
+                           wct_peak_margin = wct_peak_margin[i], log = logger)
 
         except Exception as e:
             logger.error("Error while identifying layer boundaries ")
@@ -144,7 +144,7 @@ def main(args=None):
         try:
             geom = geom_prop(rl_flag, bases, tops, alt_arr[i], prod_arr[i], log = logger)
 
-            # debug_layers(date = dt_start_arr[i], i_d = f'b{wave}', alt = alt_arr[i], 
+            #debug_layers(date = dt_start_arr[i], i_d = f'b{wave}', alt = alt_arr[i], 
             #               sig = prod_arr[i], wct = wct, 
             #               sig_err = prod_err_arr[i], wct_err = wct_err,
             #               geom = geom, max_alt = 20., 
@@ -176,8 +176,8 @@ def main(args=None):
                 dir_out = os.path.join(cfg.scc['output-dir'],meas_id)
                 geom_dts = \
                     export_nc(geom, metadata = metadata[i], alpha = alphas[i], 
-                              wave = wave[i], snr_factor = snr_factor, 
-                              wct_peak_margin = wct_peak_margin, 
+                              wave = wave[i], snr_factor = snr_factor[i], 
+                              wct_peak_margin = wct_peak_margin[i], 
                               fname = fname, dir_out = dir_out)
             except Exception as e:
                 logger.error("Error while creating the netcdf files ")
